# nulink-web3

Fix Web3.py bugs for [nulink](https://www.nulink.org/). Forked by [web3.py](https://github.com/ethereum/web3.py/releases/tag/v6.0.0-beta.1) version 6.0.0b1.

A Python library for interacting with Ethereum, inspired by [web3.js](https://github.com/ethereum/web3.js).

* Python 3.6+ support

---

## Quickstart

[Get started in 5 minutes](https://web3py.readthedocs.io/en/latest/quickstart.html) or
[take a tour](https://web3py.readthedocs.io/en/latest/overview.html) of the library.

## Documentation

For additional guides, examples, and APIs, see the [documentation](https://web3py.readthedocs.io/en/latest/).
